@@ -26,7 +26,7 @@ respondToAuthChallengeHeaders = {
 	"x-amz-target" : "AWSCognitoIdentityProviderService.RespondToAuthChallenge",
 }
 
-baseAuthUrl = "cognito-idp.us-east-e.amazonaws.com"
+baseAuthUrl = "https://cognito-idp.us-east-1.amazonaws.com"
 
 n_hex = 'FFFFFFFFFFFFFFFFC90FDAA22168C234C4C6628B80DC1CD1' + '29024E088A67CC74020BBEA63B139B22514A08798E3404DD' + \
         'EF9519B3CD3A431B302B0A6DF25F14374FE1356D6D51C245' + 'E485B576625E7EC6F44C42E9A637ED6B0BFF5CB6F406B7ED' + \
